==> ideaIC-15.0.3-sources.jar: com/intellij/vcs/log/VcsLogUi.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.vcs.log;

import com.intellij.vcs.log.graph.PermanentGraph;
import org.jetbrains.annotations.NotNull;

public interface VcsLogUi {

  @NotNull
  VcsLogFilterUi getFilterUi();

  @NotNull
  VcsLogDataPack getDataPack();

  void addHighlighter(@NotNull VcsLogHighlighter highlighter);
  void removeHighlighter(@NotNull VcsLogHighlighter highlighter);

  void addLogListener(@NotNull VcsLogListener listener);
  void removeLogListener(@NotNull VcsLogListener listener);

  void setBranchesPanelVisible(boolean visible);

  boolean areGraphActionsEnabled();

  boolean isMultipleRoots();
  boolean isShowRootNames();

  void setBekType(@NotNull PermanentGraph.SortType bekType);
  @NotNull PermanentGraph.SortType getBekType();

  void setShowRootNames(boolean showRootNames);

  boolean isHighlighterEnabled(@NotNull String id);

  void setHighlighterEnabled(@NotNull String id, boolean enabled);
}

==> ideaIC-145.1503.17-sources.jar: com/intellij/vcs/log/VcsLogUi.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.vcs.log;

import com.intellij.vcs.log.graph.PermanentGraph;
import org.jetbrains.annotations.NotNull;

public interface VcsLogUi {

  @NotNull
  VcsLogFilterUi getFilterUi();

  @NotNull
  VcsLogDataPack getDataPack();

  void addLogListener(@NotNull VcsLogListener listener);

  void removeLogListener(@NotNull VcsLogListener listener);

  void setBranchesPanelVisible(boolean visible);

  boolean isBranchesPanelVisible();

  boolean areGraphActionsEnabled();

  boolean isMultipleRoots();

  boolean isShowRootNames();

  void setLongEdgeVisibility(boolean visibility);

  boolean areLongEdgesVisible();

  void setBekType(@NotNull PermanentGraph.SortType bekType);

  @NotNull
  PermanentGraph.SortType getBekType();

  void setShowRootNames(boolean showRootNames);

  boolean isHighlighterEnabled(@NotNull String id);

  void setHighlighterEnabled(@NotNull String id, boolean enabled);

  boolean isShowDetails();

  void setShowDetails(boolean showDetails);
}
